<?php

/**
 * -----------------------------------------------------------------------
 * TermContent
 * Ein Plugin für moziloCMS (http://mozilo.de/)
 * -----------------------------------------------------------------------
 */

# zum entwickeln
# error_reporting(-1);
# ini_set('display_errors', 1);


class TermContent extends Plugin {

    private $cur_TS;     // enthält im Konstruktor den aktuellen Timestamp
    private $debug;      // zentraler Debug-Schalter
    private $debug_out;  // zentraler Debug-Buffer

    /**
     * -----------------------------------------------------------------------
     * Konstrutkor
     * -----------------------------------------------------------------------
     */
    public function __construct() {
        date_default_timezone_set('Europe/Berlin');
        // Eigenschaften setzen
        $this->cur_TS = $_SERVER['REQUEST_TIME']; // aktuellen Timestamp abstellen
        $this->debug = false;
        $this->debug_out = "<pre><hr>***** Debugausgabe *****\n\n";
        parent::__construct();
    }


    /**
     * -----------------------------------------------------------------------
     * getContent()
     * -----------------------------------------------------------------------
     *
     * Notation:
     * ---------
     *  MUSS [0] |  MUSS [1]  | MUSS [2]             | OPTIONAL [3]    | OPTIONAL [4]
     *  von      |  bis       | Content in Zeitraum
     *  von      |  bis       | Content in Zeitraum  | Text außerhalb
     *  von      |  bis       | Content in Zeitraum  | Text davor      | Text danach
     *
     * -----------------------------------------------------------------------
     */
	public function getContent($value) {

        $aValues = explode("|", $value);

        // {TermContent|DEBUG|...}
        $this->debug = false;
        if ($aValues[0] == "DEBUG") {
            $this->debug = true;
            // debug element löschen und Array-Index erneuern
            unset($aValues[0]);
            $aValues = array_values($aValues);
        }

        // sind die nötigen Werte (die Pflichtfelder) vorhanden?
        if (!isset($aValues[0], $aValues[1], $aValues[2])) {
            return $this->buildErrorMsg("Die ersten 3 Pflichtfelder sind nicht vollständig vorhanden - siehe Pluginbeschreibung.");
        }

        // Input-Werte verarbeiten

        // Von
        $tsFrom = $this->convertToTimestamp($aValues[0], false);
        if ($tsFrom == false) {
            return $this->buildErrorMsg("Von-Wert kann nicht korrekt interpretiert werden.");
        }

        // Bis
        $tsTo = $this->convertToTimestamp($aValues[1], true);
        if ($tsTo == false) {
            return $this->buildErrorMsg("Bis-Wert kann nicht korrekt interpretiert werden.");
        }

        $contentDuring = $aValues[2];
        $contentBefore = (isset($aValues[3])) ? $aValues[3] : "";
        $contentAfter  = (isset($aValues[4])) ? $aValues[4] : $contentBefore;

        // Plugin Ausgabebuffer
        $output = "";

        // -------------------------------------------------------
        // Debug-Ausgabe (Bufferinitialisierung siehe Konstruktor)
        if ($this->debug) {
            $this->debug_out .= "\n";
            $this->debug_out .= "Plugin-Aufruf: <br />".$value."\n\n";
            $this->debug_out .= "Eingabe-Von: #" . $aValues[0]."#\n";
            $this->debug_out .= "Konvertiert zu TS: ". $tsFrom."\n";
            $this->debug_out .= "TS entspricht: ".date("Y-m-d H:i:s", $tsFrom)."\n\n";

            $this->debug_out .= "Eingabe-Bis: #" . $aValues[1]."#\n";
            $this->debug_out .= "Konvertiert zu TS: ". $tsTo."\n";
            $this->debug_out .= "TS entspricht: ".date("Y-m-d H:i:s", $tsTo)."\n\n";

            $this->debug_out .= "Jetzt: ".date("Y-m-d H:i:s", $this->cur_TS)."\n";
            $this->debug_out .= "Jetzt TS: " . $this->cur_TS."\n";
            $this->debug_out .= "Aktuelle Zeitzone: ".date_default_timezone_get()."\n";
            $this->debug_out .= "PHP-Version: ".phpversion()."\n\n";
            $this->debug_out .= "***** Ende Debugausgabe *****<hr></pre>";

            // debug-Ausgabe ergänzen
            $output .= $this->debug_out;
        }
        // -------------------------------------------------------

        if ($this->cur_TS >= $tsFrom && $this->cur_TS <= $tsTo) {
            // während zeitraum
            $output .= $contentDuring;

        } elseif ($this->cur_TS <= $tsFrom) {
            // vor zeitraum
            $output .= $contentBefore;

        } elseif ($this->cur_TS >= $tsTo) {
            // nach zeitraum
            $output .= $contentAfter;

        } else {
            // dürfte nicht vorkommen
            $output .= $this->buildErrorMsg("Ausnahmefehler - bitte Pluginautor hausl78 mit aufrufenden Plugin-Code melden:<br />Code:<br />". $value);
        }

        return $output;
	}


    /**
     * -----------------------------------------------------------------------
     * getConfig()
     * -----------------------------------------------------------------------
     */
	public function getConfig() {
	}

    /**
     * -----------------------------------------------------------------------
     * getInfo()
     * -----------------------------------------------------------------------
     */
	public function getInfo() {
	  global $ADMIN_CONF;
	  $language = $ADMIN_CONF->get("language");

        $info['deDE'] = array(
	      // Plugin-Name
	      "<b>TermContent</b> Version 2018-10-24",
	      // CMS-Version
	      "2.0",
	      // Kurzbeschreibung
	      'Terminabhängige Anzeige von Inhalten. Es können vor, während und nach
	      einem definiertem Zeitraum unterschiedliche Inhalte ausgegeben werden.<br /><br />

	      '.$this->boldText("Nutzung:").'<br /><br />

	      Speziellen Inhalt nur während eines gewissen Zeitraums anzeigen:<br />
	      {TermContent|ZeitpunktVon|ZeitpunktBis|Inhalt während Zeitraums}<br /><br />

	      Oder unterschiedlicher Inhalt während und außerhalb der Zeitraums:
	      {TermContent|ZeitpunktVon|ZeitpunktBis|Inhalt während Zeitraums|Inhalt außerhalb Zeitraums}<br /><br />

          Oder davor und danach unterschiedliche Ausgaben: <br />
          {TermContent|ZeitpunktVon|ZeitpunktBis|Inhalt während Zeitraums|Inhalt vor Zeitraum|Inhalt nach Zeitraum}<br /><br />

	      '.$this->boldText("Angabe der Formate:").'<br /><br />

	      Datum und Uhrzeit: 2012-09-02 15:00<br /><br />
	      Nur Datum: 2012-09-02<br />
	      Bei der reinen Datumsangabe wird bei "von" als Uhrzeit "00:00:00" ergänzt und bei "bis" als Uhrzeit "23:59:59".<br /><br />

	      Uhrzeit: 15:00:00 (oder 15:00)<br />
	      Sekunden müssen nicht angegeben werden, werden dann autom. mit "00" vervollständigt.<br /><br />

	      Trennzeichen für Datum und/oder Uhrzeit ("-", ":" und Leerzeichen) müssen grundsätzlich nicht angeben werden.
	      Es wäre damit zB. statt 2012-09-02 15:00 auch 201209021500 erlaubt. Ist einfacher zu tippen,
	      aber auch schwieriger zu lesen ;-).<br /><br />

	      '.$this->boldText("Beispiele:").'<br /><br />

          Uhrzeit:<br />
          {TermContent|11:00|13:00|Mahlzeit!|Guten Tag!}<br />
          {TermContent|10:00|17:00|Guten Tag!|Guten Morgen!|Guten Abend!}
          <br /><br />

	      Ein Tag:<br />
	      {TermContent|2012-09-01|2012-09-01|Nur heute gibts Sommerschlussverkauf!}
	      <br /><br />

	      Inhalt für während und außerhalb des Zeitraums:<br />
	      {TermContent|2012-09-01|2012-09-30|Jetzt ist Angebotszeit|Leider keine Angebote}<br /><br />

          Inhalt für vor, während, und nach dem Zeitraum:<br />
          {TermContent|2012-09-01|2012-09-30|Jetzt ist Angebotszeit|Im September kommen Angebote|Angebote leider verpasst.}<br /><br />

          '.$this->boldText("Erweiterte Funktionen:").'<br /><br />
          '.$this->boldText("Kontrollfunkion / Debug:").'<br />
          Gibt man den optionalen ersten zusätzlichen Parameter DEBUG an, dann werden zB. zur Kontrolle beim Aufruf des Plugins sämtliche Details angezeigt,
          wie die einzelenen Übergebenen Datums/Zeitwerte interpretiert werden und der aktuelle Datums/Zeitwert, etc..<br />
          zB. {TermContent|DEBUG|2012-09-01|2012-09-01|Heute ist der erste September.}
          <br /><br />
          '.$this->boldText("Sonderangaben:").'<br />
          Da die Datum/Zeit-Eingabewerte direkt von der PHP-funktion strtotime() verarbeitet werden, sind auch
          spezielle Varianten möglich (einfach mal versuchen) zB.<br />
          {TermContent|monday|monday|Heute ist wieder mal Montag.}<br />
          {TermContent|friday|sunday|Wochenende!}<br />
          Wie oben angegeben kann man mit DEBUG dann genau sehen, welcher Wert dann für monday etc.. tatsächlich verwendet wird.<br /><br />
          Bei Fragen bitte einfach im Forum melden.
          ',

	      // Name des Autors
	      "hausl78",
	      // Download-URL
	      "http://www.mozilo.de/",
        array(
            '{TermContent| }' => '{TermContent|Von|Bis|Text während Zeitraum|Text außerhalb Zeitraum}',
            '{TermContent| }' => '{TermContent|Von|Bis|Text während Zeitraum|Text vor Zeitraum|Text nach Zeitraum}')
	    );

        #if (isset($info[$language])) {
        #  return $info[$language];
        #} else {
          return $info['deDE'];
        #}
	}

    /**
     * -----------------------------------------------------------------------
     * Konvertiert Datums-String in Timestamp
     * -----------------------------------------------------------------------
     *
     * Input-Formate:
     * --------------
     * 1500           oder 15:00               Uhrzeit
     * 20101225       oder 2010-12-25          Datum
     * 201012251500   oder 2010-12-25 15:00    Datum und kurze Uhrzeit (Sek. mit 00 gefüllt)
     * 20101225123010 oder 2010-12-25 12:30:10 Datum und komplette Uhrzeit
     *
     * $addToFullDay:
     * -------------
     *  false = Wenn nur Datum angegeben, wird mit der Uhrzeit 00:00:00 vervollständigt
     *  true  = Wenn nur Datum angegeben, wird mit der Uhrzeit 23:59:59 vervollständigt
     */
    private function convertToTimestamp($str, $addToFullDay) {
        $ts = strtotime( trim($str) );
        if ($ts == false or $ts == -1) return false;  // Vor PHP 5.1.0 gab die Funktion -1 im Fehlerfall zurück.
        if ($this->debug) $this->debug_out .= "convertToTimestamp() - Zeit-Anteil: ". date('His', $ts)."\n";
        if ($addToFullDay && date('His', $ts) == "000000") {
            $ts = strtotime('+86399 second', $ts);  // 86399 sek. = 23:59:59 (hh:mm:ss)
        }
        return $ts;
    }


    /**
     * ----------------------------------------------------------------------
     * Gibt Fehlermeldung aus
     * ----------------------------------------------------------------------
     */
    private function buildErrorMsg($msg) {
        return '<span class="deadlink">Fehler im Plugin TermContent: '.$msg.'</span>';
    }


    /**
     * ----------------------------------------------------------------------
     * In der Pluginbeschreibung was fett schreiben
     * ----------------------------------------------------------------------
     */
    private function boldText($str) {
        return '<span style="font-weight:bold;">'.$str.'</span>';
    }


} // class
